# Changelog

## v0.7.23

- feat: added a new image description caching mechanism to PptxFileParser, DocxFilePaser and PdfFileParser. 

Note: this will be released as a patch because I'll be accumulating features to release in a single feature release. (and because I need it now in work lol)
